@@ -84,6 +84,13 @@ extern void string_list_append (struct string_list *list, char *string);
 /* Sort LIST using dir_path_cmp () */
 extern void string_list_dir_path_sort (struct string_list *list);
 
+/* Is PATH included in LIST?  Update *IDX to move within LIST.
+
+   LIST is assumed to be sorted using dir_path_cmp (), successive calls to this
+   function are assumed to use PATH values increasing in dir_path_cmp (). */
+extern bool string_list_contains_dir_path (const struct string_list *list,
+					   size_t *idx, const char *path);
+
 /* An open database */
 struct db
 {
